Uses the method-of-moments estimator based on the harmonic number relationship for i.i.d. parallel exponentials: ET = H_m / lambda. Returns a spread of initial values to break permutation symmetry.
Uses the method-of-moments estimator based on the harmonic number relationship for i.i.d. parallel exponentials: ET = H_m / lambda. Returns a spread of initial values to break permutation symmetry.